<?php
$lang['abbr_length'] = 'L';
$lang['abbr_width'] = 'W';
$lang['abbr_height'] = 'H';
$lang['add'] = 'L&auml;gg till';
$lang['addcategory'] = 'L&auml;gg till en kategori';
$lang['addfielddef'] = 'L&auml;gg till ett f&auml;lt';
$lang['adjustable'] = 'Justerbar';
$lang['addproduct'] = 'L&auml;gg till en produkt';
$lang['add_attrib_set'] = 'L&auml;gg till attribut';
$lang['add_category_field'] = 'Associerande f&auml;lt med kategori: &quot;%s&quot;';
$lang['add_hierarchy_item'] = 'L&auml;gg till hierarki objekt';
$lang['add_option'] = 'L&auml;gg till ett attribut alternativ';
$lang['admin_only'] = 'Detta attribut kan endast ses av admin?';
$lang['align_ul'] = 'Toppen till v&auml;nster';
$lang['align_uc'] = 'Toppen centrerat';
$lang['align_ur'] = 'Toppen h&ouml;ger';
$lang['align_ml'] = 'Mitten till v&auml;nster';
$lang['align_mc'] = 'Centrerat';
$lang['align_mr'] = 'Mitten till h&ouml;ger';
$lang['align_ll'] = 'Nederst till v&auml;nster';
$lang['align_lc'] = 'Nederst Centrerat';
$lang['align_lr'] = 'Nederst till h&ouml;ger';
$lang['all'] = 'Alla';
$lang['allcategories'] = 'Alla kategorier';
$lang['any'] = 'Vilken';
$lang['areyousure'] = '&Auml;r du s&auml;ker?';
$lang['areyousure_deleteproduct'] = '&Auml;r du s&auml;ker p&aring; att du verkligen vill ta bort den h&auml;r produkten, och alla de kompletterande information f&ouml;r den?';
$lang['ascending'] = 'Stigande';
$lang['attribute_name'] = 'Attribut namn';
$lang['automatic'] = 'Automatiskt';
$lang['byhierarchytemplates'] = 'Hierarkimallar';
$lang['byhierarchytemplate_addedit'] = 'L&auml;gg till/Redigera Hierarkimall';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['category'] = 'Kategori';
$lang['categoryexists'] = 'En kategori med det namnet finns redan';
$lang['categorylisttemplates'] = 'Kategorimallar';
$lang['categorylisttemplate_addedit'] = 'L&auml;gg till/redigera kategorimall';
$lang['centimeters'] = 'Centimeter';
$lang['checkbox'] = 'Kryssruta';
$lang['confirm_delete_hierarchy_node'] = '&Auml;r du s&auml;ker p&aring; att du vill ta bort denna nod? Alla produkter som anv&auml;nder denna nod kommer inte att tillh&ouml;ra n&aring;gon hierarki';
$lang['confirm_import'] = '&Auml;r du s&auml;ker p&aring; att du verkligen vill g&ouml;ra detta? \ n \ nImproper inst&auml;llningar, eller en ogiltigt konfigurationsfil kunde helt f&ouml;rd&auml;rvat fungerande system.';
$lang['copy'] = 'Kopiera';
$lang['copy_category'] = 'Kopiera Kategori';
$lang['createddate'] = 'Skapad datum';
$lang['current_value'] = 'Nuvarande v&auml;rde';
$lang['data'] = 'Data ';
$lang['default'] = 'Standard';
$lang['defaulttemplates'] = 'Standardmallar';
$lang['default_template_notice'] = '<strong>Notis:</strong> Inneh&aring;llet i dessa text omr&aring;den anv&auml;nds f&ouml;r att best&auml;mma standardinneh&aring;ll av dina mallar n&auml;r du klickar p&aring; &quot;L&auml;gg till mall&quot; i l&auml;mplig mall flik. Redigering av en text i dessa omr&aring;den kommer att ha omedelbar effekt p&aring; din webbplats.';
$lang['delete'] = 'Radera';
$lang['delete_attribset'] = 'Radera attribut';
$lang['delete_hierarchy_item'] = 'Radera hierarki objektet';
$lang['descending'] = 'Fallande';
$lang['description'] = 'Beskrivning';
$lang['details'] = 'Detaljer';
$lang['detailtemplates'] = 'Detaljmall';
$lang['detailtemplate_addedit'] = 'L&auml;gg till/redigera en detaljmall';
$lang['dimensions'] = 'Dimensioner';
$lang['disabled'] = 'Inaktiverad';
$lang['draft'] = 'Utkast';
$lang['dropdown'] = 'Nedrullningsbar';
$lang['dropdown_options'] = 'Dropdown Val <em>(g&auml;ller endast f&ouml;r dropdown omr&aring;den)</em><br/><br/><em>(en post per rad)</em>';
$lang['edit'] = 'Redigera';
$lang['edit_attribset'] = 'Redigera attribut';
$lang['edit_attribsets'] = 'Redigera attributupps&auml;ttningar';
$lang['edit_attribsets_for'] = 'Redigera attributupps&auml;ttningar f&ouml;r';
$lang['edit_attributes'] = 'Redigera attributer';
$lang['edit_category'] = 'Redigera kategori';
$lang['edit_category_fields'] = 'Redigera kategori f&auml;ltet';
$lang['edit_hierarchy_item'] = 'Redigera hieraki objektet';
$lang['error_attribset_exists'] = 'En attribut med det namnet finns redan';
$lang['error_duplicate_sku'] = 'Detta SKU v&auml;rdet finns redan';
$lang['error_fieldvalue_empty'] = 'F&auml;ltets v&auml;rde kan inte vara tomt';
$lang['error_fileformat'] = 'Filformatsproblem';
$lang['error_filenotfound'] = 'Filen hittades inte';
$lang['error_fileopen'] = 'Problem att &ouml;ppna fil% s';
$lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it&#039;s own parent)';
$lang['error_invalid_name'] = 'F&auml;ltets v&auml;rde &auml;r ogiltig (inneh&aring;ller icke alfanumeriska tecken)';
$lang['error_missingparam'] = 'En n&ouml;dv&auml;ndig parameter saknas eller &auml;r ogiltig';
$lang['error_nameused'] = 'Ett objekt med det namnet anv&auml;nds redan';
$lang['error_nofieldtype'] = 'V&auml;lj f&auml;lt typ';
$lang['error_noname'] = 'Du m&aring;ste uppge ett namn';
$lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
$lang['error_permissiondenied'] = 'Nekat tillst&aring;nd';
$lang['error_product_aliasused'] = 'Det specificerade alias anv&auml;nds redan';
$lang['error_product_nameused'] = 'En produkt med det namnet finns redan';
$lang['error_product_notfound'] = 'Den beg&auml;rda produkten kunde inte hittas';
$lang['error_product_skuused'] = 'SKU-v&auml;rdet anv&auml;nds redan av en annan produkt';
$lang['error_price_adjustment'] = 'Ogiltig prisjusterings v&auml;rde f&ouml;r objektet %s';
$lang['error_upload_failed'] = 'Uppladdnings fel: %s';
$lang['expire_six_months'] = 'Efter 6 m&aring;nader';
$lang['expire_one_year'] = 'Efter 1 &aring;r';
$lang['expire_two_year'] = 'Efter 2 &aring;r';
$lang['extra1'] = 'Extra f&auml;lt 1';
$lang['extra2'] = 'Extra f&auml;lt 2';
$lang['field'] = 'F&auml;lt';
$lang['fielddef'] = 'F&auml;ltdefinition';
$lang['fielddefs'] = 'F&auml;ltdefinitioner';
$lang['file'] = 'Fil';
$lang['filters'] = 'Filter';
$lang['firstpage'] = '<<';
$lang['general_settings'] = 'Standard inst&auml;llningar';
$lang['go'] = 'Vidare';
$lang['help'] = '<h3>What does this do?</h3>
<p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is &#039;taxable&#039; or not.</p>
  <p>This module provides for up to two images per product, custom field definitions, and for the ability to descriminate private from public data.</p>
<h3>Features:</h3>
<ul>
  <li>Numerous Views</li>
    <ul>
      <li>Summary view</li>
      <li>Category List View</li>
      <li>Detail view</li> 
      <li>Hierarchy Drill-down View</li>
    </ul>
  <li>Entirely Database Template Driven</li>
  <p>Numerous templates of each type can be defined, defaults specified for each type, and the template used for each particular view can be specified as a parameter</p>
  <li>Sorting and pagination in the summary view</li>
  <li>Products can exist in multiple categories</li>
  <li>Numerous custom fields can be defined, including images</li>
  <li>Automatic thumbnail creation</li>
  <li>Admin defined fields</li>
  <li>Product attributes (including price adjustment)</li>
  <li>Weight and taxable fields (for use in e-commerce solutions)</li>
  <li>Products can have a status (published or draft) in order to hide products from public display at any time</li>
  <li>Pretty URL Support</li>
  <li><strong>More...</strong></li>
</ul>

<h3>How Do I Use It:</h3>
<ul>
<li>Set preferences</li>
<p>Usually this is just a formality.  You should specify your default weight units, and your default currency symbol for your local environment.</p>
<li>Setup users and permissions</li>
<p>This module uses the &#039;Modify Templates&#039; permission to allow users to be able to modify the various templates that can be used by this module.  As well, the &#039;Modify Site Preferences&#039; permission is needed to be able to adjust the modules preferences.  In order to have the ability to modify field definitions, categories, or products, your users will need the &#039;Modify Products&#039; permission.</p>
<li>(optional) Define one or more categories</li>
<p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the &#039;Categories&#039; tab in the Product Managers admin section, and clicking &#039;Add A Category&#039;.  From there you will be prompted for a category name.</p>
<li>(optional) Define one or more custom fields</li>
<p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
<p>Currently six types of custom fields are available: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea, dropdown, and file&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
<li>Create one or more products</li>
<p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can also specify if the product is taxable.</p>
<p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
<p>If custom fields are defined, then input fields appropriate to the type of custom field will appear and allow you to specify data for each of them.  This data is optional.</p>
<li>Add the appropriate tags into your page templates or page content</li>
<p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
<p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category=&#039;categoryname&#039;}</code></p>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs or to file a bug report, please visit the cms made simple <a href="http://dev.cmsmadesimple.org">Developers Forge</a> and do a search for &#039;Products&#039;</li>
<li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
<li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
</ul>';
$lang['hierarchy'] = 'Hierarki';
$lang['hierarchy_position'] = 'Hierarki position';
$lang['id'] = 'ID';
$lang['imagetext'] = 'Bild';
$lang['image_handling_settings'] = 'Bildhanterings inst&auml;llningar';
$lang['import_from_csv'] = 'Importera produkter fr&aring;n CSV-fil';
$lang['inches'] = 'Tum';
$lang['include_children'] = 'Inkludera children?';
$lang['info_alnumonly'] = 'Endast alfanumeriska tecken. Inga blanksteg, citattecken eller icke skrivelse / nummer kombinationer';
$lang['info_attribtemplate'] = 'M&ouml;jliga variabler &auml;r: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
$lang['info_autowatermark'] = 'Vattenst&auml;mpels inst&auml;llningarna &auml;r h&auml;mtade fr&aring;n CGExtensions Module';
$lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
$lang['info_cart_module_params'] = 'Dessa parametrar finns till den valda kundvagnsmodulen fr&aring;n produktdetalj och sammanfattning';
$lang['info_createfields'] = 'Skapa automatiskt ett ok&auml;nt produktf&auml;lt? <em> (De kommer att skapas som textf&auml;lt) </ em>';
$lang['info_createcategories'] = 'Automatiskt skapa produktkategorier f&ouml;r att matcha dem i CSV-filen, om det inte redan finns';
$lang['info_createhierarchy'] = 'Automatiskt skapa produkt hierarkier f&ouml;r att matcha dem i CSV-filen om det inte redan finns';
$lang['info_decimal_units'] = 'Detta system f&ouml;rst&aring;r (.) som decimalteckenseparator. dvs: <strong>5,25</strong>';
$lang['info_delimiter'] = 'Ange vilket tecken (eller tecken) som separera varje f&auml;lt';
$lang['info_duplicateproducts'] = 'Ange hur systemet ska hantera en produkt vilkets namn redan finns i CSV-filen';
$lang['info_fielddefs_tab'] = '<strong>Notis: </strong> Alla f&auml;lt som definieras h&auml;r &auml;r tillg&auml;ngliga f&ouml;r alla produkter.';
$lang['info_fieldproblems'] = 'Problem uppstod n&auml;r man har att g&ouml;ra med en eller flera egna f&auml;lt. &Aring;tg&auml;rden &auml;r klar, men du b&ouml;r unders&ouml;ka och r&auml;tta till dessa problem';
$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
$lang['info_imagepath'] = 'V&auml;gen (i f&ouml;rh&aring;llande till inlagda katalogen) var bilderna som avses i importfilen, finns';
$lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
$lang['info_price_adjustment'] = 'Giltiga v&auml;rden &auml;r +-*#.##';
$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
$lang['info_publicfield'] = 'Offentliga f&auml;lt som &auml;r tillg&auml;ngliga f&ouml;r allm&auml;nheten att se';
$lang['label'] = 'Etikett';
$lang['label_skip'] = 'Hoppa &ouml;ver';
$lang['label_overwrite'] = 'Skriv &ouml;ver';
$lang['lastpage'] = '>>';
$lang['last_modified'] = 'Senast uppdaterad';
$lang['logotext'] = 'Andra bild';
$lang['maxlength'] = 'Maximal l&auml;ngd <em>(till&auml;mpas endast p&aring; textrutans omr&aring;den)</em>';
$lang['modifieddate'] = '&Auml;ndrat datum';
$lang['module_description'] = 'En modul f&ouml;r att hantera ett sortiment av produkter, deras pris, bilder, etc, och g&ouml;ra det m&ouml;jligt f&ouml;r anv&auml;ndare att bygga en kundvagn';
$lang['move_down'] = 'Flytta ner';
$lang['move_up'] = 'Flytta upp';
$lang['name'] = 'Produktnamn';
$lang['needpermission'] = 'Du har inte r&auml;ttigheter f&ouml;r: %s';
$lang['new_category_name'] = 'Nytt kategorinamn';
$lang['nextpage'] = '>';
$lang['no'] = 'Nej';
$lang['nonamegiven'] = 'Inget produktnamn har uppgetts';
$lang['none'] = 'Ingen';
$lang['of'] = 'Av';
$lang['page'] = 'Sida';
$lang['page_of'] = 'Sida %s of %s';
$lang['page_limit'] = 'Max antal sidor';
$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
<ul>
  <li>hierarchy -- Display a product list by hierarchy</li>
  <li>categorylist - Display a list of product categories</li>
  <li><em>default</em> - Display a summary of products</li>
  <li>details - Display a detail view of a single product</li>
</ul>';
$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
$lang['param_categorylisttemplate'] = 'Anv&auml;ndbar endast med kategorilistans &aring;tg&auml;rder, den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r hur listan ska visas. Om inget v&auml;rde anges kommer den nuvarande standardmall av denna typ anv&auml;ndas.';
$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
$lang['param_detailpage'] = 'Detta anger pageid eller alias som b&ouml;r anv&auml;ndas f&ouml;r att visa en detalj rapport.';
$lang['param_detailtemplate'] = 'Den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r hur detalj-l&auml;ge visas. Om inget v&auml;rde anges, d&aring; kommer den nuvarande standardmall av denna typ att anv&auml;ndas.';
$lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
$lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
$lang['param_hierarchytemplate'] = 'Den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r hierarkin displayen. Om inget v&auml;rde anges, d&aring; kommer den nuvarande standardmall av denna typ att anv&auml;ndas.';
$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
$lang['param_pagelimit'] = 'Anv&auml;ndbar endast med <em> standard </ em> &aring;tg&auml;rder, denna parameter anger hur m&aring;nga objekt ska anges p&aring; varje sida.';
$lang['param_parent'] = 'Anv&auml;ndbar endast i <em> hierarki </ em> &aring;tg&auml;rder, denna parameter anger hierarkin id b&ouml;rjans plats i rapporten.';
$lang['param_productid'] = 'Anv&auml;ndbar endast med detalj &aring;tg&auml;rder, den h&auml;r parametern anger vilken produkt som ska anv&auml;ndas f&ouml;r visning.';
$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
$lang['param_showall'] = 'Applicable only to the categorylist action, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
$lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
<ul>
  <li><strong>asc</strong> -- Ascending order</li>
  <li>desc -- Descending order</li>
</ul>';
$lang['param_sortby'] = 'Applicable only in summary mode, this parameter determines the sorting of the output products.  Possible values are:
<ul>
  <li><strong>product_name</strong></li>
  <li>price -- The product base price</li>
  <li>status -- Draft or published</li>
  <li>random -- Display in random order on each request</li>
  <li>created -- The creation date for this company record</li>
  <li>modified -- The modified date for this company record</li>
</ul>';
$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summjary view';
$lang['param_summarytemplate'] = 'Den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r sammanfattnings l&auml;ge. Om inget v&auml;rde anges, d&aring; kommer den nuvarande standardmall av denna typ att anv&auml;ndas.';
$lang['parent'] = 'F&ouml;reg&aring;ende';
$lang['postinstall'] = 'Products modulen &auml;r nu installerad';
$lang['postuninstall'] = 'Products modulen &auml;r nu borttagen samt all tillh&ouml;rande data';
$lang['preferences'] = 'Inst&auml;llningar';
$lang['preuninstall'] = 'Genom att ta bort den h&auml;r modulen s&aring; kommer ocks&aring; att all tillh&ouml;rande data tas bort, &auml;r du s&auml;ker p&aring; att du vill forts&auml;tta?';
$lang['price'] = 'Pris';
$lang['price_adjustment'] = 'Prisjustering';
$lang['prevpage'] = '<';
$lang['product'] = 'Produkt';
$lang['productname'] = 'Produktnamn';
$lang['products'] = 'Produkter';
$lang['product_detail_settings'] = 'Produkt Detaljinst&auml;llningar';
$lang['product_hierarchy'] = 'Produkt Hierarki';
$lang['product_manager'] = 'Produkt Manager';
$lang['progress'] = 'Framsteg';
$lang['prompt'] = 'Uppmana';
$lang['prompt_add_attribset'] = 'L&auml;gg till / redigera attributupps&auml;ttning';
$lang['prompt_allowed_filetypes'] = 'Till&aring;t att ladda upp filer med dessa f&ouml;rl&auml;ngningar (f&ouml;r filtypen f&auml;lt)';
$lang['prompt_allowed_imagetypes'] = 'Till&aring;t uppladdning av bilder med dessa filt&auml;ndelser(f&ouml;r bildf&auml;lten)';
$lang['prompt_attribtemplate'] = 'Mall f&ouml;r visning av produktattributer i en dropdown';
$lang['prompt_autothumbnail'] = 'Automatiskt skapa tumnagelbild (thumbnail) av bilder';
$lang['prompt_autothumbnail_size'] = 'Maximal storlek p&aring; tumnagelbild (thumbnail)';
$lang['prompt_autopreviewimg'] = 'Automatiskt skapa f&ouml;rhandsgranskningsbilder av bilder';
$lang['prompt_autopreviewimg_size'] = 'Maximal storlek p&aring; f&ouml;rhandsgranskningsbild';
$lang['prompt_autowatermark'] = 'Automatiskt placera vattenm&auml;rke p&aring; bilder';
$lang['prompt_applicable'] = 'Aktivera automatiskt f&ouml;r alla nya produkter';
$lang['prompt_batchsize'] = 'Partistorlek';
$lang['prompt_cart_module'] = 'Kundvagnsmodul';
$lang['prompt_cart_module_params'] = 'Parametrar f&ouml;r Kundvagnsmodul';
$lang['prompt_createcategories'] = 'Skapa kategorier';
$lang['prompt_createfields'] = 'Skapa produktf&auml;lt?';
$lang['prompt_createhierarchy'] = 'Skapa produkthirarki';
$lang['prompt_csvfile'] = 'Ladda upp CSV-fil';
$lang['prompt_currencycode'] = 'Valutakod';
$lang['prompt_currencysymbol'] = 'Valutasymbol';
$lang['prompt_default_status'] = 'Som standard har alla nya produkter denna status';
$lang['prompt_default_taxable'] = 'Som standard &auml;r alla n ya produkter beskattningsbara';
$lang['prompt_deleteproductfiles'] = 'Ta bort alla filer i samband med produkten n&auml;r produkten skall raderas?';
$lang['prompt_delimiter'] = 'F&auml;lt avgr&auml;nsare';
$lang['prompt_detailpage'] = 'Standard detaljsida';
$lang['prompt_detailsfor'] = 'Detaljer f&ouml;r %s';
$lang['prompt_duplicateproducts'] = 'Hur man hanterar duplikat produkter?';
$lang['prompt_false'] = 'Falsk';
$lang['prompt_handleimages'] = 'Hantera bilder?';
$lang['prompt_imagepath'] = 'Bilds&ouml;kv&auml;g';
$lang['prompt_lengthunits'] = 'L&auml;ngdenheter';
$lang['prompt_notfound_behavior'] = 'Vad ska h&auml;nda n&auml;r en produkt inte kan visas?';
$lang['prompt_notfound_404'] = 'Generera ett 404-fel';
$lang['prompt_notfound_301'] = 'Generera ett 301-omdirigering';
$lang['prompt_notfound_errormsg'] = 'Visa ett felmeddelande';
$lang['prompt_notfound_msg'] = 'Felmeddelande f&ouml;r n&auml;r en produkt inte kan hittas';
$lang['prompt_notfound_page'] = 'Sida att g&ouml;ra permanent omdirigering till?';
$lang['prompt_prod_detailpage'] = 'Standardsida f&ouml;r Produkt detaljvyer';
$lang['prompt_products_matching'] = 'Produkter matchar %s';
$lang['prompt_summarysortorder'] = 'Standard sorteringsordning i sammandrags l&auml;ge';
$lang['prompt_summarysorting'] = 'Standard sorteringsordning i f&auml;ltens sammandrags l&auml;ge';
$lang['prompt_template'] = 'Mallens k&auml;lla';
$lang['prompt_true'] = 'Sann';
$lang['prompt_urlprefix'] = 'Prefix att anv&auml;nda p&aring; alla webbadresser som &auml;r inriktad p&aring; denna modulen';
$lang['prompt_use_detailpage_for_search'] = 'Anv&auml;nd den h&auml;r sidan f&ouml;r s&ouml;kresultat f&ouml;r <em> (&aring;sidos&auml;tter s&ouml;kresultat sidparametern i modulen) </ em>';
$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
$lang['prompt_weightunits'] = 'Vikt enheter';
$lang['public'] = '&Auml;r detta ett offentligt f&auml;lt?';
$lang['published'] = 'Publicerad';
$lang['random'] = 'Slumpvis';
$lang['resettofactory'] = '&Aring;terst&auml;ll till fabriksinst&auml;llningar';
$lang['return'] = '&Aring;terv&auml;nd';
$lang['return_to_top'] = '&Aring;terv&auml;nd till toppen';
$lang['root'] = 'ROOT';
$lang['search_description'] = 'Search Property Description';
$lang['search_expr'] = 'Ska fr&aring;gan matcha alla eller n&aring;gon av testen nedan?';
$lang['search_name'] = 'Search Property Name';
$lang['search_price'] = 'Prisintervall';
$lang['searchtemplate_addedit'] = 'L&auml;gg till / redigera S&ouml;k formul&auml;rsmall';
$lang['searchtemplates'] = 'S&ouml;k mall';
$lang['select_one'] = 'V&auml;lj en';
$lang['sku'] = 'SKU';
$lang['sort_by'] = 'Sortera';
$lang['sort_order'] = 'Sorteringsorder';
$lang['status'] = 'Status ';
$lang['submit'] = 'Spara';
$lang['subscription'] = 'Subscription';
$lang['subscr_expiry'] = 'Expiry';
$lang['subscr_expiry2'] = 'Expires';
$lang['subscr_monthly'] = 'Monthly';
$lang['subscr_delperiod'] = 'Delivery Frequency';
$lang['subscr_delperiod2'] = 'Levererad';
$lang['subscr_payperiod'] = 'Payment Frequency';
$lang['subscr_payperiod2'] = 'Betald';
$lang['subscr_quarterly'] = 'Quarterly';
$lang['subscr_semianually'] = 'Semi Anually';
$lang['subscr_yearly'] = '&Aring;rlig';
$lang['summarytemplates'] = 'Summeringsmallar';
$lang['summarytemplate_addedit'] = 'L&auml;gg till/redigera en summeringsmall';
$lang['taxable'] = 'Beskattningsbara';
$lang['test'] = 'Test ';
$lang['textarea'] = 'Text-Area';
$lang['textbox'] = 'Text-Input';
$lang['title_byhierarchy_dflttemplate'] = 'Standardhierarkimall';
$lang['title_categorylist_dflttemplate'] = 'Standardkategorimall';
$lang['title_detail_dflttemplate'] = 'Standarddetaljmall';
$lang['title_search_dflttemplate'] = 'Ny standard s&ouml;kmall';
$lang['title_summary_dflttemplate'] = 'Standardsammanfattningsmall';
$lang['type'] = 'Typ';
$lang['update'] = 'Uppdatera';
$lang['upload'] = 'V&auml;lj en fil som ska laddas upp';
$lang['url_alias'] = 'Url Alias';
$lang['valid'] = 'Giltig';
$lang['value'] = 'V&auml;rde';
$lang['values'] = 'V&auml;rden';
$lang['view'] = 'Granska';
$lang['viewable_fields'] = 'V&auml;lj anpassade f&auml;lt f&ouml;r att visa i tabellen';
$lang['watermark_location'] = 'Vattenm&auml;rkets placering';
$lang['weight'] = 'Vikt';
$lang['yes'] = 'Ja?';
$lang['utma'] = '156861353.622613290.1282068801.1285618628.1285621370.19';
$lang['utmz'] = '156861353.1284652314.14.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['qca'] = 'P0-1267218368-1282068801788';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1285621370';
?>